brokkr is a simple distributed task queue library for Rust.
It allows queueing tasks and processing them in the background with independent workers and should be simple to integrate in existing applications and deployments.
Structs
- Brokkr
- Interface with the Redis backend.
- Job
- A job and its metadata / state information.
- Worker
- Worker process.
Enums
- Error
- Main error type for this crate.
- JobState
- The different states that a
Jobcan be in. - Worker
Status - Possible statuses of a
Workerprocess.
Traits
- Encodable
- Represent data that is safe to be passed around either through the Redis backend (through Serde serialisation) or across threads for execution.
- Perform
- The
Performtrait is used to mark a task as executable and encode the logic associated with this task.
Type Aliases
- Result
- Result type for this crate.